@@ -1,19 +1,17 @@
+from typing import Literal
+
 from vk_dev import Condition, peer
 
+
 class Path(Condition):
     """
     Message's path
-    path: Enum[str] = [
-        'chat',
-        'direct'
-    ]
     """
 
-    def __init__(self, path):
+    def __init__(self, path: Literal['chat', 'direct']):
         self._path = path
 
     def code(self, event, pl):
-        if event.object.message.peer_id < peer:
+        if event.object.message.peer_id > peer:
             return 'direct' == self._path
-        else:
-            return 'chat' == self._path
+        return 'chat' == self._path
