@@ -1,19 +1,20 @@
 from functools import wraps
+from typing import Callable, Awaitable, Union
 import inspect
 
 from .dot_dict import DotDict
 
 
-def payload(func):
+def payload(func) -> Union[Callable[..., DotDict], Callable[..., Awaitable[DotDict]]]:
     """
     Decorator for payload functions
     """
     if inspect.iscoroutinefunction(func):
-        async def wrapper(event, *args, **kwargs):
+        async def wrapper(event: str, *args, **kwargs) -> DotDict:
             res = await func(event=event, *args, **kwargs)
             return DotDict(res)
     else:
-        def wrapper(event, *args, **kwargs):
+        def wrapper(event: str, *args, **kwargs) -> DotDict:
             return DotDict(func(event=event, *args, **kwargs))
 
     wrapper = wraps(func)(wrapper)
